interface SignalCandles extends Record<string, unknown> {
    open: number;
    close: number;
    low: number;
    high: number;
    timestamp: string;
}
interface SignalOptions {
    openKey: string;
    closeKey: string;
    lowKey: string;
    highKey: string;
    timestampISO8601Key: string;
    emaPeriod: number;
    emaBuyRatio: number;
    emaSellRatio: number;
    macdFastPeriod: number;
    macdSlowPeriod: number;
    macdSignalPeriod: number;
    williamsRPeriod: number;
}
interface SignalOutput {
    open: number;
    close: number;
    low: number;
    high: number;
    timestamp: string;
    ema: number;
    emaBuy: number;
    emaSell: number;
    macd: number;
    macdSignal: number;
    macdHistogram: number;
    isIntersecting: boolean;
    williamsR: number;
    signal: 'buy' | 'sell' | 'hold';
}
/**
 * Calculate buy and sell signals for a given set of candles.
 *
 * @typedef {SignalCandles} SignalCandles
 * @typedef {SignalOutput} SignalOutput
 * @param {SignalCandles[]} candles The candles to calculate signals for.
 * @returns {SignalOutput[]} The signals for the given candles.
 */
export declare function Signal(candles: Partial<SignalCandles>[], options?: Partial<SignalOptions>): SignalOutput[];
export {};
